Structs
- Direct
Embedded Channel Backend - Minimal in-process channel backend that accepts messages immediately.
- Direct
Embedded Conversation Backend - Minimal in-process conversation backend that accepts sends immediately.
- Embedded
Channel Handle - Channel handle that publishes through direct in-process references.
- Embedded
Config - Configuration for embedded SDK handles.
- Embedded
Conversation Handle - Conversation handle that sends through direct in-process references.
- Empty
Lifecycle Stream - Stream used when a conversation has no lifecycle events buffered locally.
- Ready
Result - Ready future used by SDK handles that complete an operation synchronously.
- SdkSubscription
- Stream used by SDK handles when no typed messages are buffered locally.
Traits
- Embedded
Channel Backend - Direct in-process channel backend used by embedded handles.
- Embedded
Channel Message - Type-erased view of a typed channel message passed to an embedded backend.
- Embedded
Conversation Backend - Direct in-process conversation backend used by embedded handles.
- Embedded
Conversation Message - Type-erased view of a typed conversation message passed to an embedded backend.