SdkSubscription

Struct SdkSubscription 

pub struct SdkSubscription<M> { /* private fields */ }
Stream used by SDK handles when no typed messages are buffered locally.

Implementations

Source

impl<M> SdkSubscription<M>

pub const fn empty() -> Self

Creates an empty typed subscription stream.

pub const fn error(error: SdkError) -> Self

Creates a subscription stream that surfaces a setup error to the caller.

pub const fn is_empty(&self) -> bool

Returns true when this local subscription has no pending setup error.