EmbeddedConversationMessage

Trait EmbeddedConversationMessage 

pub trait EmbeddedConversationMessage {
    // Required method
    fn type_name(&self) -> &'static str;
}
Type-erased view of a typed conversation message passed to an embedded backend.

Required Methods

fn type_name(&self) -> &'static str

Returns the Rust type name used for diagnostics and backend routing.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors