pub struct TcpRemoteTransport { /* private fields */ }Expand description
Real TCP transport that exchanges canonical wire frames with a liminal server.
Implementations
Sourceimpl TcpRemoteTransport
impl TcpRemoteTransport
Sourcepub fn connect(server_address: &ServerAddress) -> Result<Self, SdkError>
pub fn connect(server_address: &ServerAddress) -> Result<Self, SdkError>
Connects to server_address, completes the handshake, and returns a ready transport.
Errors
Returns SdkError::Connection when the TCP connection cannot be
established, and SdkError::Protocol when the handshake frames cannot be
encoded, sent, or are rejected by the server.