pub enum DetachLossOutcome {
Parked,
Refused(DetachReplayRefusalReason),
}Expand description
Outcome of reporting a detach-send transport loss.
Variants
Parked
The typed fate consumed the send authority and parked replay.
Refused(DetachReplayRefusalReason)
The report was refused typed with unchanged replay state.