pub enum CommandRefusal {
InvalidPhase {
phase: DriverPhase,
},
ExchangeOutstanding,
}Expand description
Typed refusal for a command that is illegal in the current driver state.
Variants
InvalidPhase
The command is not legal in the current phase.
Fields

phase: DriverPhaseThe refusing phase.
ExchangeOutstanding
A correlated exchange is already outstanding (the Q-B rule).