pub enum EventRefusal {
OpenedWithoutOpenCommand,
BinaryBeforeEstablished,
}Expand description
Typed refusal for an event that is illegal in the current phase.
Variants
OpenedWithoutOpenCommand
Opened arrived while no open command was outstanding.
BinaryBeforeEstablished
A binary message arrived before the socket was established.