Module embedded

Module embedded 

Structs

DirectEmbeddedChannelBackend
Minimal in-process channel backend that accepts messages immediately.
DirectEmbeddedConversationBackend
Minimal in-process conversation backend that accepts sends immediately.
EmbeddedChannelHandle
Channel handle that publishes through direct in-process references.
EmbeddedConfig
Configuration for embedded SDK handles.
EmbeddedConversationHandle
Conversation handle that sends through direct in-process references.
EmptyLifecycleStream
Stream used when a conversation has no lifecycle events buffered locally.
ReadyResult
Ready future used by SDK handles that complete an operation synchronously.
SdkSubscription
Stream used by SDK handles when no typed messages are buffered locally.

Traits

EmbeddedChannelBackend
Direct in-process channel backend used by embedded handles.
EmbeddedChannelMessage
Type-erased view of a typed channel message passed to an embedded backend.
EmbeddedConversationBackend
Direct in-process conversation backend used by embedded handles.
EmbeddedConversationMessage
Type-erased view of a typed conversation message passed to an embedded backend.