Module remote

Module remote 

Structs

NoJitter
Deterministic jitter source for lifecycle integration tests and explicit reconnect calls.
PushClient
A connected client that consumes server pushes and sends correlated replies.
PushedFrame
A frame the server pushed to this client.
RemoteChannelHandle
Channel handle that communicates through SDK-internal wire protocol transport.
RemoteConfig
Configuration for remote SDK handles.
RemoteConversationHandle
Conversation handle that communicates through SDK-internal wire protocol transport.
ServerAddress
Application-level address for a remote liminal server.
TcpRemoteTransport
Real TCP transport that exchanges canonical wire frames with a liminal server.

Enums

SdkChannelHandle
Runtime-selected channel handle that keeps deployment differences behind configuration.
SdkConfig
Deployment-mode configuration used by the SDK builders.
SdkConversationHandle
Runtime-selected conversation handle that keeps deployment differences behind configuration.

Functions

build_channel_handle
Builds a channel handle selected by SdkConfig.
build_conversation_handle
Builds a conversation handle selected by SdkConfig.