Structs
- NoJitter
- Deterministic jitter source for lifecycle integration tests and explicit reconnect calls.
- Push
Client - A connected client that consumes server pushes and sends correlated replies.
- Pushed
Frame - A frame the server pushed to this client.
- Remote
Channel Handle - Channel handle that communicates through SDK-internal wire protocol transport.
- Remote
Config - Configuration for remote SDK handles.
- Remote
Conversation Handle - Conversation handle that communicates through SDK-internal wire protocol transport.
- Server
Address - Application-level address for a remote liminal server.
- TcpRemote
Transport - Real TCP transport that exchanges canonical wire frames with a liminal server.
Enums
- SdkChannel
Handle - Runtime-selected channel handle that keeps deployment differences behind configuration.
- SdkConfig
- Deployment-mode configuration used by the SDK builders.
- SdkConversation
Handle - Runtime-selected conversation handle that keeps deployment differences behind configuration.
Functions
- build_
channel_ handle - Builds a channel handle selected by
SdkConfig. - build_
conversation_ handle - Builds a conversation handle selected by
SdkConfig.