pub enum RemoteParticipantInbound {
Applied {
value: ServerValue,
provenance: ParticipantResponseProvenance,
},
Refused {
value: ServerValue,
reason: ClientInboundRefusalReason,
provenance: ParticipantResponseProvenance,
},
Push {
value: ServerPush,
provenance: ParticipantResponseProvenance,
},
}Expand description
Typed result of one decoded participant frame on the real receive path.
Variants
Applied
The protocol crate correlated and applied a semantic response.
Fields

value: ServerValueExact applied server value.

provenance: ParticipantResponseProvenanceConnection/attempt that delivered it.
Refused
The protocol crate retained the response and aggregate unchanged.
Fields

value: ServerValueExact refused server value.

reason: ClientInboundRefusalReasonClosed crate refusal reason, including conservative ambiguity.

provenance: ParticipantResponseProvenanceConnection/attempt that delivered it.
Push
Server push decoded in the client direction; no correlation rule applies.
Fields

value: ServerPushExact pushed value.

provenance: ParticipantResponseProvenanceConnection/attempt that delivered it.